@@ -38,6 +38,7 @@ LB_EXT_IDS_POOL_PREFIX = 'pool_'
 LB_EXT_IDS_LISTENER_PREFIX = 'listener_'
 LB_EXT_IDS_MEMBER_PREFIX = 'member_'
 LB_EXT_IDS_HM_KEY = 'octavia:healthmonitor'
+LB_EXT_IDS_HMS_KEY = 'octavia:healthmonitors'
 LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
 LB_EXT_IDS_VIP_PORT_ID_KEY = 'neutron:vip_port_id'
@@ -103,3 +104,7 @@ LB_SELECTION_FIELDS_MAP = {
     constants.LB_ALGORITHM_SOURCE_IP: ["ip_src", "ip_dst"],
     None: ["ip_src", "ip_dst", "tp_src", "tp_dst"],
 }
+
+# HM events status
+HM_EVENT_MEMBER_PORT_ONLINE = ['online']
+HM_EVENT_MEMBER_PORT_OFFLINE = ['offline']
